@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -42,7 +42,7 @@ __all__ = ("SimpleDBClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -70,7 +70,7 @@ class Exceptions:
 
 class SimpleDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html)
     """
 
@@ -83,24 +83,24 @@ class SimpleDBClient(BaseClient):
         """
 
     def batch_delete_attributes(
-        self, *, DomainName: str, Items: List["DeletableItemTypeDef"]
+        self, *, DomainName: str, Items: Sequence["DeletableItemTypeDef"]
     ) -> None:
         """
         Performs multiple DeleteAttributes operations in a single call, which reduces
         round trips and latencies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.batch_delete_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.batch_delete_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#batch_delete_attributes)
         """
 
     def batch_put_attributes(
-        self, *, DomainName: str, Items: List["ReplaceableItemTypeDef"]
+        self, *, DomainName: str, Items: Sequence["ReplaceableItemTypeDef"]
     ) -> None:
         """
         The `BatchPutAttributes` operation creates or replaces attributes within one or
         more items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.batch_put_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.batch_put_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#batch_put_attributes)
         """
 
@@ -108,7 +108,7 @@ class SimpleDBClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#can_paginate)
         """
 
@@ -116,7 +116,7 @@ class SimpleDBClient(BaseClient):
         """
         The `CreateDomain` operation creates a new domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#create_domain)
         """
 
@@ -125,13 +125,13 @@ class SimpleDBClient(BaseClient):
         *,
         DomainName: str,
         ItemName: str,
-        Attributes: List["AttributeTypeDef"] = None,
+        Attributes: Sequence["AttributeTypeDef"] = None,
         Expected: "UpdateConditionTypeDef" = None
     ) -> None:
         """
         Deletes one or more attributes associated with an item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.delete_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.delete_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#delete_attributes)
         """
 
@@ -139,7 +139,7 @@ class SimpleDBClient(BaseClient):
         """
         The `DeleteDomain` operation deletes a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#delete_domain)
         """
 
@@ -149,21 +149,21 @@ class SimpleDBClient(BaseClient):
         number of items and attributes in the domain, and the size of the attribute
         names and values.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.domain_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.domain_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#domain_metadata)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#generate_presigned_url)
         """
 
@@ -172,13 +172,13 @@ class SimpleDBClient(BaseClient):
         *,
         DomainName: str,
         ItemName: str,
-        AttributeNames: List[str] = None,
+        AttributeNames: Sequence[str] = None,
         ConsistentRead: bool = None
     ) -> GetAttributesResultTypeDef:
         """
         Returns all of the attributes associated with the specified item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.get_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.get_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#get_attributes)
         """
 
@@ -188,7 +188,7 @@ class SimpleDBClient(BaseClient):
         """
         The `ListDomains` operation lists all domains associated with the Access Key ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.list_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.list_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#list_domains)
         """
 
@@ -197,13 +197,13 @@ class SimpleDBClient(BaseClient):
         *,
         DomainName: str,
         ItemName: str,
-        Attributes: List["ReplaceableAttributeTypeDef"],
+        Attributes: Sequence["ReplaceableAttributeTypeDef"],
         Expected: "UpdateConditionTypeDef" = None
     ) -> None:
         """
         The PutAttributes operation creates or replaces attributes in an item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.put_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.put_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#put_attributes)
         """
 
@@ -214,20 +214,20 @@ class SimpleDBClient(BaseClient):
         The `Select` operation returns a set of attributes for `ItemNames` that match
         the select expression.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Client.select)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Client.select)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#select)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/paginators.html#listdomainspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["select"]) -> SelectPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.38/reference/services/sdb.html#SimpleDB.Paginator.Select)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/sdb.html#SimpleDB.Paginator.Select)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/paginators.html#selectpaginator)
         """
