@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -70,7 +70,7 @@ BatchDeleteAttributesRequestRequestTypeDef = TypedDict(
     "BatchDeleteAttributesRequestRequestTypeDef",
     {
         "DomainName": str,
-        "Items": List["DeletableItemTypeDef"],
+        "Items": Sequence["DeletableItemTypeDef"],
     },
 )
 
@@ -78,7 +78,7 @@ BatchPutAttributesRequestRequestTypeDef = TypedDict(
     "BatchPutAttributesRequestRequestTypeDef",
     {
         "DomainName": str,
-        "Items": List["ReplaceableItemTypeDef"],
+        "Items": Sequence["ReplaceableItemTypeDef"],
     },
 )
 
@@ -98,7 +98,7 @@ _RequiredDeletableItemTypeDef = TypedDict(
 _OptionalDeletableItemTypeDef = TypedDict(
     "_OptionalDeletableItemTypeDef",
     {
-        "Attributes": List["AttributeTypeDef"],
+        "Attributes": Sequence["AttributeTypeDef"],
     },
     total=False,
 )
@@ -118,7 +118,7 @@ _RequiredDeleteAttributesRequestRequestTypeDef = TypedDict(
 _OptionalDeleteAttributesRequestRequestTypeDef = TypedDict(
     "_OptionalDeleteAttributesRequestRequestTypeDef",
     {
-        "Attributes": List["AttributeTypeDef"],
+        "Attributes": Sequence["AttributeTypeDef"],
         "Expected": "UpdateConditionTypeDef",
     },
     total=False,
@@ -169,7 +169,7 @@ _RequiredGetAttributesRequestRequestTypeDef = TypedDict(
 _OptionalGetAttributesRequestRequestTypeDef = TypedDict(
     "_OptionalGetAttributesRequestRequestTypeDef",
     {
-        "AttributeNames": List[str],
+        "AttributeNames": Sequence[str],
         "ConsistentRead": bool,
     },
     total=False,
@@ -243,7 +243,7 @@ _RequiredPutAttributesRequestRequestTypeDef = TypedDict(
     {
         "DomainName": str,
         "ItemName": str,
-        "Attributes": List["ReplaceableAttributeTypeDef"],
+        "Attributes": Sequence["ReplaceableAttributeTypeDef"],
     },
 )
 _OptionalPutAttributesRequestRequestTypeDef = TypedDict(
@@ -287,7 +287,7 @@ ReplaceableItemTypeDef = TypedDict(
     "ReplaceableItemTypeDef",
     {
         "Name": str,
-        "Attributes": List["ReplaceableAttributeTypeDef"],
+        "Attributes": Sequence["ReplaceableAttributeTypeDef"],
     },
 )
 
